:py:mod:`holisticai.bias.plots`
=================================

.. automodule:: holisticai.bias.plots
    :no-members:
    :no-inherited-members:


**Binary Classification Plots**

.. autosummary::
    :toctree: .generated/
    
    abroca_plot

**Multiclass Classification Plots**

.. autosummary::
    :nosignatures:
    :template: function.rst
    :toctree: .generated/
    
    accuracy_bar_plot
    frequency_plot
    disparate_impact_plot
    frequency_matrix_plot
    statistical_parity_plot

**Regression Plots**

.. autosummary::
    :nosignatures:
    :template: function.rst
    :toctree: .generated/
    
    disparate_impact_curve
    mae_bar_plot
    rmse_bar_plot
    statistical_parity_curve
    success_rate_curve
    success_rate_curves

**Recommender Plots**

.. autosummary::
    :nosignatures:
    :template: function.rst
    :toctree: .generated/
    
    exposure_diff_plot
    exposure_ratio_plot
    long_tail_plot

**Report Plots**

.. autosummary::
    :nosignatures:
    :template: function.rst
    :toctree: .generated/
    
    bias_metrics_report
